import type { Reducer } from 'redux';
import type { QueryBarThunkAction } from './query-bar-store';
import type { QueryFormFields } from '../constants/query-properties';
type AIQueryStatus = 'ready' | 'fetching' | 'success';
export type AIQueryState = {
    errorMessage: string | undefined;
    errorCode: string | undefined;
    isInputVisible: boolean;
    aiPromptText: string;
    status: AIQueryStatus;
    aiQueryFetchId: number;
};
export declare const initialState: AIQueryState;
export declare const enum AIQueryActionTypes {
    AIQueryStarted = "compass-query-bar/ai-query/AIQueryStarted",
    AIQueryCancelled = "compass-query-bar/ai-query/AIQueryCancelled",
    AIQueryFailed = "compass-query-bar/ai-query/AIQueryFailed",
    AIQuerySucceeded = "compass-query-bar/ai-query/AIQuerySucceeded",
    CancelAIQuery = "compass-query-bar/ai-query/CancelAIQuery",
    ShowInput = "compass-query-bar/ai-query/ShowInput",
    HideInput = "compass-query-bar/ai-query/HideInput",
    ChangeAIPromptText = "compass-query-bar/ai-query/ChangeAIPromptText",
    AtlasServiceDisableAIFeature = "compass-query-bar/ai-query/AtlasServiceDisableAIFeature"
}
type HideInputAction = {
    type: AIQueryActionTypes.HideInput;
};
type ChangeAIPromptTextAction = {
    type: AIQueryActionTypes.ChangeAIPromptText;
    text: string;
};
export declare const changeAIPromptText: (text: string) => ChangeAIPromptTextAction;
type AIQueryStartedAction = {
    type: AIQueryActionTypes.AIQueryStarted;
    fetchId: number;
};
type AIQueryFailedAction = {
    type: AIQueryActionTypes.AIQueryFailed;
    errorMessage: string;
    statusCode?: number;
    errorCode?: string;
};
export type AIQuerySucceededAction = {
    type: AIQueryActionTypes.AIQuerySucceeded;
    fields: QueryFormFields;
};
export declare const runAIQuery: (userInput: string) => QueryBarThunkAction<Promise<void>, AIQueryStartedAction | AIQueryFailedAction | AIQuerySucceededAction>;
type CancelAIQueryAction = {
    type: AIQueryActionTypes.CancelAIQuery;
};
export declare const cancelAIQuery: () => QueryBarThunkAction<void, CancelAIQueryAction>;
export declare const disableAIFeature: () => QueryBarThunkAction<void>;
export declare const showInput: () => QueryBarThunkAction<Promise<void>>;
export declare const hideInput: () => QueryBarThunkAction<void, HideInputAction>;
declare const aiQueryReducer: Reducer<AIQueryState>;
export { aiQueryReducer };
//# sourceMappingURL=ai-query-reducer.d.ts.map